@@ -1051,3 +1051,131 @@ class ListTargetProjectsAsyncPager:
 
     def __repr__(self) -> str:
         return "{0}<{1!r}>".format(self.__class__.__name__, self._response)
+
+
+class ListReplicationCyclesPager:
+    """A pager for iterating through ``list_replication_cycles`` requests.
+
+    This class thinly wraps an initial
+    :class:`google.cloud.vmmigration_v1.types.ListReplicationCyclesResponse` object, and
+    provides an ``__iter__`` method to iterate through its
+    ``replication_cycles`` field.
+
+    If there are more pages, the ``__iter__`` method will make additional
+    ``ListReplicationCycles`` requests and continue to iterate
+    through the ``replication_cycles`` field on the
+    corresponding responses.
+
+    All the usual :class:`google.cloud.vmmigration_v1.types.ListReplicationCyclesResponse`
+    attributes are available on the pager. If multiple requests are made, only
+    the most recent response is retained, and thus used for attribute lookup.
+    """
+
+    def __init__(
+        self,
+        method: Callable[..., vmmigration.ListReplicationCyclesResponse],
+        request: vmmigration.ListReplicationCyclesRequest,
+        response: vmmigration.ListReplicationCyclesResponse,
+        *,
+        metadata: Sequence[Tuple[str, str]] = ()
+    ):
+        """Instantiate the pager.
+
+        Args:
+            method (Callable): The method that was originally called, and
+                which instantiated this pager.
+            request (google.cloud.vmmigration_v1.types.ListReplicationCyclesRequest):
+                The initial request object.
+            response (google.cloud.vmmigration_v1.types.ListReplicationCyclesResponse):
+                The initial response object.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+        """
+        self._method = method
+        self._request = vmmigration.ListReplicationCyclesRequest(request)
+        self._response = response
+        self._metadata = metadata
+
+    def __getattr__(self, name: str) -> Any:
+        return getattr(self._response, name)
+
+    @property
+    def pages(self) -> Iterator[vmmigration.ListReplicationCyclesResponse]:
+        yield self._response
+        while self._response.next_page_token:
+            self._request.page_token = self._response.next_page_token
+            self._response = self._method(self._request, metadata=self._metadata)
+            yield self._response
+
+    def __iter__(self) -> Iterator[vmmigration.ReplicationCycle]:
+        for page in self.pages:
+            yield from page.replication_cycles
+
+    def __repr__(self) -> str:
+        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)
+
+
+class ListReplicationCyclesAsyncPager:
+    """A pager for iterating through ``list_replication_cycles`` requests.
+
+    This class thinly wraps an initial
+    :class:`google.cloud.vmmigration_v1.types.ListReplicationCyclesResponse` object, and
+    provides an ``__aiter__`` method to iterate through its
+    ``replication_cycles`` field.
+
+    If there are more pages, the ``__aiter__`` method will make additional
+    ``ListReplicationCycles`` requests and continue to iterate
+    through the ``replication_cycles`` field on the
+    corresponding responses.
+
+    All the usual :class:`google.cloud.vmmigration_v1.types.ListReplicationCyclesResponse`
+    attributes are available on the pager. If multiple requests are made, only
+    the most recent response is retained, and thus used for attribute lookup.
+    """
+
+    def __init__(
+        self,
+        method: Callable[..., Awaitable[vmmigration.ListReplicationCyclesResponse]],
+        request: vmmigration.ListReplicationCyclesRequest,
+        response: vmmigration.ListReplicationCyclesResponse,
+        *,
+        metadata: Sequence[Tuple[str, str]] = ()
+    ):
+        """Instantiates the pager.
+
+        Args:
+            method (Callable): The method that was originally called, and
+                which instantiated this pager.
+            request (google.cloud.vmmigration_v1.types.ListReplicationCyclesRequest):
+                The initial request object.
+            response (google.cloud.vmmigration_v1.types.ListReplicationCyclesResponse):
+                The initial response object.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+        """
+        self._method = method
+        self._request = vmmigration.ListReplicationCyclesRequest(request)
+        self._response = response
+        self._metadata = metadata
+
+    def __getattr__(self, name: str) -> Any:
+        return getattr(self._response, name)
+
+    @property
+    async def pages(self) -> AsyncIterator[vmmigration.ListReplicationCyclesResponse]:
+        yield self._response
+        while self._response.next_page_token:
+            self._request.page_token = self._response.next_page_token
+            self._response = await self._method(self._request, metadata=self._metadata)
+            yield self._response
+
+    def __aiter__(self) -> AsyncIterator[vmmigration.ReplicationCycle]:
+        async def async_generator():
+            async for page in self.pages:
+                for response in page.replication_cycles:
+                    yield response
+
+        return async_generator()
+
+    def __repr__(self) -> str:
+        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)
